@@ -20,18 +20,12 @@ def handler_decorator(handler):
     # Sentry
     sentry_sdk.init(
       dsn = os.environ['SENTRY_DSN'] if "SENTRY_DSN" in os.environ else "",
-      environment=os.environ['ENVIRONMENT'] if "ENVIRONMENT" in os.environ else "",
-      sample_rate=1.0
+      traces_sample_rate=1.0
     )
     try:
       return handler(*args)
     except Exception as err:
-      print("sending error to sentry: ", os.environ['SENTRY_DSN'])
       sentry_sdk.capture_exception(err)
-      sentry_sdk.capture_message("hi decorator")
-      return {
-        "statusCode": 500,
-        "body": str(err),
-      }
+      raise Exception(str(err))
 
   return wrapper
\ No newline at end of file
